@@ -22,8 +22,8 @@ is_dataRetrieval_user <- function() {
 
 wqp_message <- function(){
   message("NEWS: USGS data availability and format are changing. 
-Beginning in mid-March 2024 the data obtained from legacy profiles
-will not include new USGS data or recent updates to existing data. 
+Beginning in March 2024 the data obtained from legacy WQP profiles
+do not include new USGS data or recent updates to existing data. 
 To view the status of changes in data availability and code functionality, visit:
 https://doi-usgs.github.io/dataRetrieval/articles/Status.html
 If you have additional questions about these changes, 
@@ -31,12 +31,8 @@ email CompTools@usgs.gov.")
 }
 
 nwis_message <- function(){
-  return("WARNING: Beginning in mid-March 2024, NWIS will not deliver
-new discrete water quality data or updates to existing data. 
-For updated information visit: https://waterdata.usgs.gov/nwis/qwdata
-For additional details, see:
-https://doi-usgs.github.io/dataRetrieval/articles/Status.html
-https://doi-usgs.github.io/dataRetrieval/articles/qwdata_changes.html
-If you have additional questions about the qw data service,
-email CompTools@usgs.gov.")
+  return("WARNING: NWIS does not deliver
+discrete water quality data newer than March 11, 2024
+or updates to existing data. For additional details, see:
+https://doi-usgs.github.io/dataRetrieval/articles/Status.html")
 }
