@@ -87,237 +87,230 @@ constructNWISURL <- function(siteNumbers,
     "dv", "uv", "iv", "iv_recent", "qw", "gwlevels",
     "rating", "peak", "meas", "stat", "qwdata"
   ))
-
+  
   service[service == "qw"] <- "qwdata"
   service[service == "meas"] <- "measurements"
   service[service == "uv"] <- "iv"
-
+  
   if (any(!is.na(parameterCd) & parameterCd != "all")) {
     pcodeCheck <- all(nchar(parameterCd) == 5) & all(!is.na(suppressWarnings(as.numeric(parameterCd))))
-
+    
     if (!pcodeCheck) {
       badIndex <- which(nchar(parameterCd) != 5 | is.na(suppressWarnings(as.numeric(parameterCd))))
       stop("The following pCodes appear mistyped:", paste(parameterCd[badIndex], collapse = ", "))
     }
-
+    
     if (length(parameterCd) > 200) {
       stop("Maximum parameter codes allowed is 200, please adjust data request.")
     }
   }
-
+  
   multipleSites <- length(siteNumbers) > 1
-
+  
   siteNumbers <- paste(siteNumbers, collapse = ",")
-
+  
   baseURL <- drURL(service, Access = pkg.env$access)
-
+  
   switch(service,
-    qwdata = {
-      if (multipleSites) {
-        searchCriteria <- "multiple_site_no"
-        url <- appendDrURL(baseURL, multiple_site_no = siteNumbers)
-      } else {
-        searchCriteria <- "search_site_no"
-        url <- appendDrURL(baseURL,
-          search_site_no = siteNumbers,
-          search_site_no_match_type = "exact"
-        )
-      }
-
-      multiplePcodes <- length(parameterCd) > 1
-
-      if (multiplePcodes) {
-        pCodes <- paste(parameterCd, collapse = ",")
-        url <- appendDrURL(url,
-          multiple_parameter_cds = pCodes,
-          param_cd_operator = "OR"
-        )
-      } else {
-        url <- appendDrURL(url,
-          multiple_parameter_cds = parameterCd,
-          param_cd_operator = "AND"
-        )
-      }
-
-      searchCriteria <- paste(searchCriteria, "multiple_parameter_cds", sep = ",")
-      url <- appendDrURL(url, list_of_search_criteria = searchCriteria)
-
-
-      url <- paste(url, "group_key=NONE&sitefile_output_format=html_table&column_name=agency_cd",
-        "column_name=site_no&column_name=station_nm&inventory_output=0&rdb_inventory_output=file",
-        "TZoutput=0&pm_cd_compare=Greater%20than&radio_parm_cds=previous_parm_cds&qw_attributes=0",
-        "format=rdb&rdb_qw_attributes=0&date_format=YYYY-MM-DD",
-        "rdb_compression=value",
-        sep = "&"
-      )
-      if (expanded) {
-        url <- appendDrURL(url, qw_sample_wide = "0")
-        url <- gsub("rdb_qw_attributes=0", "rdb_qw_attributes=expanded", url)
-      } else {
-        url <- appendDrURL(url, qw_sample_wide = "separated_wide")
-      }
-
-      if (nzchar(startDate)) {
-        url <- appendDrURL(url, begin_date = startDate)
-      }
-
-      if (nzchar(endDate)) {
-        url <- appendDrURL(url, end_date = endDate)
-      }
-    },
-    rating = {
-      ratingType <- match.arg(ratingType, c("base", "corr", "exsa"))
-      url <- appendDrURL(baseURL, site_no = siteNumbers, file_type = ratingType)
-    },
-    peak = {
-      url <- appendDrURL(baseURL,
-        site_no = siteNumbers,
-        range_selection = "date_range",
-        format = "rdb"
-      )
-      if (nzchar(startDate)) {
-        url <- appendDrURL(url, begin_date = startDate)
-      }
-      if (nzchar(endDate)) {
-        url <- appendDrURL(url, end_date = endDate)
-      }
-    },
-    measurements = {
-      url <- appendDrURL(baseURL,
-        site_no = siteNumbers,
-        range_selection = "date_range"
-      )
-      if (nzchar(startDate)) {
-        url <- appendDrURL(url,
-          begin_date = startDate
-        )
-      }
-      if (nzchar(endDate)) {
-        url <- appendDrURL(url, end_date = endDate)
-      }
-      if (expanded) {
-        url <- appendDrURL(url, format = "rdb_expanded")
-      } else {
-        url <- appendDrURL(url, format = "rdb")
-      }
-    },
-    stat = { # for statistics service
-
-      message("Please be aware the NWIS data service feeding this function is in BETA.\n
+         qwdata = {
+           if (multipleSites) {
+             searchCriteria <- "multiple_site_no"
+             url <- appendDrURL(baseURL, multiple_site_no = siteNumbers)
+           } else {
+             searchCriteria <- "search_site_no"
+             url <- appendDrURL(baseURL,
+                                search_site_no = siteNumbers,
+                                search_site_no_match_type = "exact"
+             )
+           }
+           
+           multiplePcodes <- length(parameterCd) > 1
+           
+           if (multiplePcodes) {
+             pCodes <- paste(parameterCd, collapse = ",")
+             url <- appendDrURL(url,
+                                multiple_parameter_cds = pCodes,
+                                param_cd_operator = "OR"
+             )
+           } else {
+             url <- appendDrURL(url,
+                                multiple_parameter_cds = parameterCd,
+                                param_cd_operator = "AND"
+             )
+           }
+           
+           searchCriteria <- paste(searchCriteria, "multiple_parameter_cds", sep = ",")
+           url <- appendDrURL(url, list_of_search_criteria = searchCriteria)
+           
+           
+           url <- paste(url, "group_key=NONE&sitefile_output_format=html_table&column_name=agency_cd",
+                        "column_name=site_no&column_name=station_nm&inventory_output=0&rdb_inventory_output=file",
+                        "TZoutput=0&pm_cd_compare=Greater%20than&radio_parm_cds=previous_parm_cds&qw_attributes=0",
+                        "format=rdb&rdb_qw_attributes=0&date_format=YYYY-MM-DD",
+                        "rdb_compression=value",
+                        sep = "&"
+           )
+           if (expanded) {
+             url <- appendDrURL(url, qw_sample_wide = "0")
+             url <- gsub("rdb_qw_attributes=0", "rdb_qw_attributes=expanded", url)
+           } else {
+             url <- appendDrURL(url, qw_sample_wide = "separated_wide")
+           }
+           
+           if (nzchar(startDate)) {
+             url <- appendDrURL(url, begin_date = startDate)
+           }
+           
+           if (nzchar(endDate)) {
+             url <- appendDrURL(url, end_date = endDate)
+           }
+         },
+         rating = {
+           ratingType <- match.arg(ratingType, c("base", "corr", "exsa"))
+           url <- appendDrURL(baseURL, site_no = siteNumbers, file_type = ratingType)
+         },
+         peak = {
+           url <- appendDrURL(baseURL,
+                              site_no = siteNumbers,
+                              range_selection = "date_range",
+                              format = "rdb"
+           )
+           if (nzchar(startDate)) {
+             url <- appendDrURL(url, begin_date = startDate)
+           }
+           if (nzchar(endDate)) {
+             url <- appendDrURL(url, end_date = endDate)
+           }
+         },
+         measurements = {
+           url <- appendDrURL(baseURL,
+                              site_no = siteNumbers,
+                              range_selection = "date_range"
+           )
+           if (nzchar(startDate)) {
+             url <- appendDrURL(url,
+                                begin_date = startDate
+             )
+           }
+           if (nzchar(endDate)) {
+             url <- appendDrURL(url, end_date = endDate)
+           }
+           if (expanded) {
+             url <- appendDrURL(url, format = "rdb_expanded")
+           } else {
+             url <- appendDrURL(url, format = "rdb")
+           }
+         },
+         stat = { # for statistics service
+           
+           message("Please be aware the NWIS data service feeding this function is in BETA.\n
           Data formatting could be changed at any time, and is not guaranteed")
-
-      # make sure only statTypes allowed for the statReportType are being requested
-      if (!grepl("(?i)daily", statReportType) &&
-        !all(grepl("(?i)mean", statType)) &&
-        !all(grepl("(?i)all", statType))) {
-        stop("Monthly and annual report types can only provide means")
-      }
-
-      # make sure dates aren"t too specific for statReportType
-      if (grepl("(?i)monthly", statReportType) &&
-        (length(unlist(gregexpr("-", startDate))) > 1 ||
-          length(unlist(gregexpr("-", endDate))) > 1)) {
-        stop("Start and end dates for monthly statReportType can only include months and years")
-      }
-      if (grepl("(?i)annual", statReportType) && (grepl("-", startDate) || grepl("-", endDate))) {
-        stop("Start and end dates for annual statReportType can only include years")
-      }
-      statType <- paste(statType, collapse = ",")
-      parameterCd <- paste(parameterCd, collapse = ",")
-      url <- appendDrURL(baseURL,
-        sites = siteNumbers,
-        statType = statType,
-        statReportType = statReportType,
-        parameterCd = parameterCd
-      )
-      if (nzchar(startDate)) {
-        url <- appendDrURL(url, startDT = startDate)
-      }
-      if (nzchar(endDate)) {
-        url <- appendDrURL(url, endDT = endDate)
-      }
-      if (!grepl("(?i)daily", statReportType)) {
-        url <- appendDrURL(url, missingData = "off")
-      }
-    },
-    { # this will be either dv, uv, groundwater
-      multiplePcodes <- length(parameterCd) > 1
-      # Check for 5 digit parameter code:
-      if (multiplePcodes) {
-        parameterCd <- paste(parameterCd, collapse = ",")
-      }
-
-      format <- match.arg(format, c("xml", "tsv", "wml1", "wml2", "rdb"))
-
-      formatURL <- switch(format,
-        xml = {
-          if ("gwlevels" == service) {
-            "waterml"
-          } else {
-            "waterml,1.1"
-          }
-        },
-        rdb = {
-          if ("gwlevels" == service) {
-            "rdb,3.0"
-          } else {
-            "rdb,1.0"
-          }
-        },
-        tsv = {
-          if ("gwlevels" == service) {
-            "rdb"
-          } else {
-            "rdb,1.0"
-          }
-        },
-        wml2 = "waterml,2.0",
-        wml1 = {
-          if ("gwlevels" == service) {
-            "waterml"
-          } else {
-            "waterml,1.1"
-          }
-        }
-      )
-
-      url <- appendDrURL(baseURL,
-        site = siteNumbers,
-        format = formatURL
-      )
-
-      if (!is.na(parameterCd)) {
-        url <- appendDrURL(url, ParameterCd = parameterCd)
-      }
-
-      if ("dv" == service) {
-        if (length(statCd) > 1) {
-          statCd <- paste(statCd, collapse = ",")
-        }
-        url <- appendDrURL(url, StatCd = statCd)
-      }
-
-      if (nzchar(startDate)) {
-        url <- appendDrURL(url, startDT = startDate)
-      } else {
-        startorgin <- "1851-01-01"
-        if ("iv" == service) startorgin <- "1900-01-01"
-        url <- appendDrURL(url, startDT = startorgin)
-      }
-
-      if (nzchar(endDate)) {
-        url <- appendDrURL(url, endDT = endDate)
-      }
-    }
+           
+           # make sure only statTypes allowed for the statReportType are being requested
+           if (!grepl("(?i)daily", statReportType) &&
+               !all(grepl("(?i)mean", statType)) &&
+               !all(grepl("(?i)all", statType))) {
+             stop("Monthly and annual report types can only provide means")
+           }
+           
+           # make sure dates aren"t too specific for statReportType
+           if (grepl("(?i)monthly", statReportType) &&
+               (length(unlist(gregexpr("-", startDate))) > 1 ||
+                length(unlist(gregexpr("-", endDate))) > 1)) {
+             stop("Start and end dates for monthly statReportType can only include months and years")
+           }
+           if (grepl("(?i)annual", statReportType) && (grepl("-", startDate) || grepl("-", endDate))) {
+             stop("Start and end dates for annual statReportType can only include years")
+           }
+           statType <- paste(statType, collapse = ",")
+           parameterCd <- paste(parameterCd, collapse = ",")
+           url <- appendDrURL(baseURL,
+                              sites = siteNumbers,
+                              statType = statType,
+                              statReportType = statReportType,
+                              parameterCd = parameterCd
+           )
+           if (nzchar(startDate)) {
+             url <- appendDrURL(url, startDT = startDate)
+           }
+           if (nzchar(endDate)) {
+             url <- appendDrURL(url, endDT = endDate)
+           }
+           if (!grepl("(?i)daily", statReportType)) {
+             url <- appendDrURL(url, missingData = "off")
+           }
+         },
+         gwlevels = {
+           
+           url <- appendDrURL(baseURL,
+                              site_no = siteNumbers,
+                              agency_cd = "USGS",
+                              format = "rdb"
+           )
+           if (nzchar(startDate)) {
+             url <- appendDrURL(url, begin_date = startDate)
+           }
+           if (nzchar(endDate)) {
+             url <- appendDrURL(url, end_date = endDate)
+           }
+           
+           url <- paste(url, "group_key=NONE",
+                         "date_format=YYYY-MM-DD",
+                         "rdb_compression=value", 
+                        sep = "&")
+           
+         },
+         { # this will be either dv, uv, groundwater
+           multiplePcodes <- length(parameterCd) > 1
+           # Check for 5 digit parameter code:
+           if (multiplePcodes) {
+             parameterCd <- paste(parameterCd, collapse = ",")
+           }
+           
+           format <- match.arg(format, c("xml", "tsv", "wml1", "wml2", "rdb"))
+           
+           formatURL <- switch(format,
+                               xml = "waterml,1.1",
+                               rdb = "rdb,1.0",
+                               tsv = "rdb,1.0",
+                               wml2 = "waterml,2.0",
+                               wml1 = "waterml,1.1"
+           )
+           
+           url <- appendDrURL(baseURL,
+                              site = siteNumbers,
+                              format = formatURL
+           )
+           
+           if (!is.na(parameterCd)) {
+             url <- appendDrURL(url, ParameterCd = parameterCd)
+           }
+           
+           if ("dv" == service) {
+             if (length(statCd) > 1) {
+               statCd <- paste(statCd, collapse = ",")
+             }
+             url <- appendDrURL(url, StatCd = statCd)
+           }
+           
+           if (nzchar(startDate)) {
+             url <- appendDrURL(url, startDT = startDate)
+           } else {
+             startorgin <- "1851-01-01"
+             if ("iv" == service) startorgin <- "1900-01-01"
+             url <- appendDrURL(url, startDT = startorgin)
+           }
+           
+           if (nzchar(endDate)) {
+             url <- appendDrURL(url, endDT = endDate)
+           }
+         }
   )
-
+  
   return(url)
 }
 
 
-
-
-
 #' Construct WQP url for data retrieval
 #'
 #' Construct WQP url for data retrieval. This function gets the data from here: \url{https://www.waterqualitydata.us}
