@@ -1,13 +1,18 @@
 #' Instantaneous value data retrieval from USGS (NWIS)
 #'
 #' Imports data from NWIS web service. This function gets the data from here:
-#' \url{https://waterservices.usgs.gov/}
-#' A list of parameter codes can be found here:
-#' \url{https://nwis.waterdata.usgs.gov/nwis/pmcodes/}
-#' A list of statistic codes can be found here:
-#' \url{https://nwis.waterdata.usgs.gov/nwis/help/?read_file=stat&format=table}.
+#' \url{https://waterservices.usgs.gov/docs/instantaneous-values/instantaneous-values-details/}
+#' Inputs to this function are just USGS site ids, USGS parameter codes,
+#' and start and end date. For a more complex query, use \code{\link{readNWISdata}},
+#' including an arguement service="uv".
+#' Not all parameter codes are available for all data.
+#' Use the function \code{\link{whatNWISdata}} to discover what data
+#' is available for a USGS site. The column data_type_cd with the values "uv"
+#' returned from \code{\link{whatNWISdata}}) are available from this service.
+#' 
 #' More information on the web service can be found here:
-#' \url{https://waterservices.usgs.gov/docs/instantaneous-values/}.
+#' \url{https://waterservices.usgs.gov/test-tools}, choosing the
+#' "Instantaneous Value Service".
 #'
 #' @param siteNumbers character USGS site number (or multiple sites).  This is usually an 8 digit number
 #' @param parameterCd character USGS parameter code.  This is usually an 5 digit number.
@@ -85,17 +90,17 @@ readNWISuv <- function(siteNumbers, parameterCd, startDate = "", endDate = "", t
   } else {
     service <- "iv_recent"
   }
-
+  
   url <- constructNWISURL(siteNumbers,
-    parameterCd,
-    startDate,
-    endDate,
-    service,
-    format = "xml"
+                          parameterCd,
+                          startDate,
+                          endDate,
+                          service,
+                          format = "xml"
   )
-
+  
   data <- importWaterML1(url, asDateTime = TRUE, tz = tz)
-
+  
   return(data)
 }
 
@@ -169,7 +174,7 @@ readNWISpeak <- function(siteNumbers,
                          endDate = "",
                          asDateTime = TRUE,
                          convertType = TRUE) {
-
+  
   # Doesn't seem to be a peak xml service
   url <- constructNWISURL(
     siteNumbers = siteNumbers,
@@ -178,17 +183,17 @@ readNWISpeak <- function(siteNumbers,
     endDate = endDate,
     service = "peak"
   )
-
+  
   data <- importRDB1(url,
-    asDateTime = asDateTime,
-    convertType = convertType
+                     asDateTime = asDateTime,
+                     convertType = convertType
   )
-
+  
   if (nrow(data) > 0) {
     if (asDateTime && convertType) {
       if ("peak_dt" %in% names(data)) {
         if (any(nchar(as.character(data$peak_dt)) <= 7, na.rm = TRUE) ||
-          any(grepl("[0-9]*-[0-9]*-00", data$peak_dt), na.rm = TRUE)) {
+            any(grepl("[0-9]*-[0-9]*-00", data$peak_dt), na.rm = TRUE)) {
           stop("Not all dates could be converted to Date object. Use convertType=FALSE to retrieve the raw text")
         } else {
           data$peak_dt <- as.Date(data$peak_dt, format = "%Y-%m-%d")
@@ -197,11 +202,11 @@ readNWISpeak <- function(siteNumbers,
           message("Some dates could not be converted to a valid date, and were returned as NA")
         }
       }
-
+      
       if ("ag_dt" %in% names(data)) data$ag_dt <- as.Date(data$ag_dt, format = "%Y-%m-%d")
     }
-
-
+    
+    
     siteInfo <- readNWISsite(siteNumbers)
     siteInfo <- merge(
       x = unique(data[, c("agency_cd", "site_no")]),
@@ -209,12 +214,12 @@ readNWISpeak <- function(siteNumbers,
       by = c("agency_cd", "site_no"),
       all.x = TRUE
     )
-
+    
     attr(data, "siteInfo") <- siteInfo
     attr(data, "variableInfo") <- NULL
     attr(data, "statisticInfo") <- NULL
   }
-
+  
   return(data)
 }
 
@@ -260,17 +265,17 @@ readNWISpeak <- function(siteNumbers,
 #' attr(data, "RATING")
 #' }
 readNWISrating <- function(siteNumber, type = "base", convertType = TRUE) {
-
+  
   # No rating xml service
   url <- constructNWISURL(siteNumber, service = "rating", ratingType = type)
-
+  
   data <- importRDB1(url, asDateTime = FALSE, convertType = convertType)
-
+  
   if ("current_rating_nu" %in% names(data)) {
     intColumns <- intColumns[!("current_rating_nu" %in% names(data)[intColumns])]
     data$current_rating_nu <- gsub(" ", "", data$current_rating_nu)
   }
-
+  
   if (nrow(data) > 0) {
     if (type == "base") {
       Rat <- grep("//RATING ", comment(data), value = TRUE, fixed = TRUE)
@@ -278,14 +283,14 @@ readNWISrating <- function(siteNumber, type = "base", convertType = TRUE) {
       Rat <- scan(text = Rat, sep = " ", what = "")
       attr(data, "RATING") <- Rat
     }
-
+    
     siteInfo <- readNWISsite(siteNumber)
-
+    
     attr(data, "siteInfo") <- siteInfo
     attr(data, "variableInfo") <- NULL
     attr(data, "statisticInfo") <- NULL
   }
-
+  
   return(data)
 }
 
@@ -351,7 +356,7 @@ readNWISmeas <- function(siteNumbers,
                          tz = "UTC",
                          expanded = FALSE,
                          convertType = TRUE) {
-
+  
   # Doesn't seem to be a WaterML1 format option
   url <- constructNWISURL(
     siteNumbers = siteNumbers,
@@ -361,24 +366,24 @@ readNWISmeas <- function(siteNumbers,
     service = "meas",
     expanded = expanded
   )
-
+  
   data <- importRDB1(
     obs_url = url,
     asDateTime = TRUE,
     tz = tz,
     convertType = convertType
   )
-
+  
   if (nrow(data) > 0) {
     if ("diff_from_rating_pc" %in% names(data)) {
       data$diff_from_rating_pc <- as.numeric(data$diff_from_rating_pc)
     }
-
+    
     url <- attr(data, "url")
     comment <- attr(data, "comment")
     queryTime <- attr(data, "queryTime")
     header <- attr(data, "headerInfo")
-
+    
     if (convertType) {
       data$measurement_dateTime <- data$measurement_dt
       data$measurement_dt <- suppressWarnings(as.Date(data$measurement_dateTime))
@@ -391,14 +396,14 @@ readNWISmeas <- function(siteNumbers,
       newOrder <- c(
         1:indexDT, indexTM, indexTZrep,
         c((indexDT + 1):ncol(data))[!(c((indexDT + 1):ncol(data)) %in%
-          c(indexTZrep, indexTM, indexTZ))],
+                                        c(indexTZrep, indexTM, indexTZ))],
         indexTZ
       )
-
+      
       data <- data[, newOrder]
     }
-
-
+    
+    
     siteInfo <- readNWISsite(siteNumbers)
     siteInfo <- merge(
       x = unique(data[, c("agency_cd", "site_no")]),
@@ -410,18 +415,33 @@ readNWISmeas <- function(siteNumbers,
     attr(data, "comment") <- comment
     attr(data, "queryTime") <- queryTime
     attr(data, "header") <- header
-
+    
     attr(data, "siteInfo") <- siteInfo
     attr(data, "variableInfo") <- NULL
     attr(data, "statisticInfo") <- NULL
   }
-
+  
   return(data)
 }
 
 #' Groundwater level measurements retrieval from USGS (NWIS)
 #'
-#' Reads groundwater level measurements from NWISweb. Mixed date/times come back from the service
+#' Imports groundwater level data from NWIS web service. This function gets the data from here:
+#' \url{https://waterservices.usgs.gov/docs/groundwater-levels/groundwater-levels-details/}
+#' Inputs to this function are just USGS site ids, USGS parameter codes,
+#' and start and end date. For a more complex query, use \code{\link{readNWISdata}},
+#' including an argument service="gwlevels".
+#' Not all parameter codes are available for all data.
+#' Use the function \code{\link{whatNWISdata}} to discover what data
+#' is available for a USGS site. The column data_type_cd with the values "gw"
+#' returned from \code{\link{whatNWISdata}}) are available from this service.
+#' 
+#' More information on the web service can be found here:
+#' \url{https://waterservices.usgs.gov/test-tools}, choosing the
+#' "Groundwater Levels Value Service".
+#' 
+#' 
+#' Mixed date/times come back from the service
 #' depending on the year that the data was collected. See \url{https://waterdata.usgs.gov/usa/nwis/gw}
 #' for details about groundwater. By default the returned dates are converted to date objects, unless convertType
 #' is specified as FALSE. Sites with non-standard date formats (i.e. lacking a day) can be affected (see examples).
@@ -473,12 +493,13 @@ readNWISmeas <- function(siteNumbers,
 #' \donttest{
 #' data <- readNWISgwl(site_id)
 #' sites <- c("434400121275801", "375907091432201")
-#' data2 <- readNWISgwl(site_id, "", "")
+#' data2 <- readNWISgwl(sites, "", "")
 #' data3 <- readNWISgwl("420125073193001", "", "")
 #' # handling of data where date has no day
-#' data4 <- readNWISgwl("425957088141001", startDate = "1980-01-01")
+#' data4 <- readNWISgwl("263819081585801", startDate = "2000-01-01")
 #'
-#' data5 <- readNWISgwl("263819081585801", parameterCd = "72019")
+#' data5 <- readNWISgwl("263819081585801", parameterCd = "72019",
+#'                      startDate = "2000-01-01")
 #' }
 readNWISgwl <- function(siteNumbers,
                         startDate = "",
@@ -493,14 +514,18 @@ readNWISgwl <- function(siteNumbers,
     service = "gwlevels",
     format = "rdb"
   )
-
+  
   data <- importRDB1(
     obs_url = url,
     asDateTime = TRUE,
     convertType = convertType,
     tz = tz
   )
-
+  
+  if(!is.na(parameterCd)){
+    data <- data[data$parameter_cd %in% parameterCd, ]
+  }
+  
   if (nrow(data) > 0 && !all(is.na(data$lev_dt))) {
     if (convertType) {
       # check that the date includes a day, based on date string length
@@ -519,7 +544,7 @@ readNWISgwl <- function(siteNumbers,
     )
     attr(data, "siteInfo") <- siteInfo
   }
-
+  
   return(data)
 }
 
@@ -591,7 +616,7 @@ readNWISgwl <- function(siteNumbers,
 #' }
 readNWISstat <- function(siteNumbers, parameterCd, startDate = "", endDate = "", convertType = TRUE,
                          statReportType = "daily", statType = "mean") {
-
+  
   # check for NAs in site numbers
   if (any(is.na(siteNumbers))) {
     siteNumbers <- siteNumbers[!is.na(siteNumbers)]
@@ -610,15 +635,15 @@ readNWISstat <- function(siteNumbers, parameterCd, startDate = "", endDate = "",
     statType = statType,
     statReportType = statReportType
   )
-
+  
   data <- importRDB1(
     obs_url = url,
     asDateTime = TRUE,
     convertType = convertType
   )
-
+  
   siteInfo <- readNWISsite(siteNumbers)
-
+  
   if (nrow(data) > 0) {
     siteInfo <- merge(
       x = unique(data[, c("agency_cd", "site_no")]),
@@ -627,9 +652,9 @@ readNWISstat <- function(siteNumbers, parameterCd, startDate = "", endDate = "",
       all.x = TRUE
     )
   }
-
+  
   attr(data, "siteInfo") <- siteInfo
-
+  
   return(data)
 }
 
@@ -698,7 +723,7 @@ readNWISuse <- function(stateCd,
                         transform = FALSE) {
   countyID <- NULL
   countyCd <- countyCd[countyCd != ""]
-
+  
   if (exists("countyCd") && !is.null(countyCd)) {
     if (!any(toupper(countyCd) == "ALL")) {
       for (c in countyCd) {
@@ -709,10 +734,10 @@ readNWISuse <- function(stateCd,
       countyID <- toupper(countyID)
     }
   }
-
+  
   years <- .capitalALL(years)
   categories <- .capitalALL(categories)
-
+  
   url <- constructUseURL(
     years = years,
     stateCd = stateCd,
@@ -723,7 +748,7 @@ readNWISuse <- function(stateCd,
     obs_url = url,
     convertType = convertType
   )
-
+  
   # for total country data arriving in named rows
   if (transform) {
     cmmnt <- comment(returned_data)
@@ -748,4 +773,4 @@ readNWISuse <- function(stateCd,
     input <- toupper(input)
   }
   return(input)
-}
+}
\ No newline at end of file
