@@ -30,7 +30,7 @@
 #' description for this help file. If no "service" argument is supplied, it
 #' will default to "Result". One way to figure out how to construct a WQP query is to go to the "Advanced" 
 #' form in the Water Quality Portal:
-#' \url{https://www.waterqualitydata.us/#mimeType=csv&providers=NWIS&providers=STEWARDS&providers=STORET}
+#' \url{https://www.waterqualitydata.us/#mimeType=csv&providers=NWIS&providers=STORET}
 #' Use the form to discover what parameters are available. Once the query is 
 #' set in the form, scroll down to the "Query URL". You will see the parameters
 #' after "https://www.waterqualitydata.us/#". For example, if you chose "Nutrient"
@@ -203,6 +203,8 @@ readWQPdata <- function(...,
                         convertType = TRUE) {
   tz <- match.arg(tz, OlsonNames())
 
+  wqp_message()
+  
   valuesList <- readWQPdots(...)
 
   service <- valuesList$service
